Airfoil in open jet -- CMF
==========================
Demonstrates CMF methods same setup as in :doc:`example_airfoil_in_open_jet_beamforming`.

It needs the measured timeseries data in :download:`example_data.h5 <../../../examples/example_data.h5>` and calibration in :download:`example_calib.xml <../../../examples/example_calib.xml>`. Both files should reside in the same directory as the :download:`example_airfoil_in_open_jet_cmf.py <../../../examples/example_airfoil_in_open_jet_cmf.py>` script.

The script produces the figure:

.. figure:: example_airfoil_in_open_jet_cmf_1.png
    :align: center
    :width: 100%
    :figwidth: 70%

.. literalinclude:: ../../../examples/example_airfoil_in_open_jet_cmf.py
